@@ -1,4 +1,5 @@
 from unittest import TestCase
+from jaseci.svc import ServiceState
 
 import jaseci.tests.jac_test_progs as jtp
 from jaseci.actor.sentinel import Sentinel
@@ -20,7 +21,7 @@ class JacTests(TestCaseHelper, TestCase):
         super().tearDown()
 
     def test_bug_check1(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtp.bug_check1)
         test_walker = sent.run_architype("init")
@@ -30,7 +31,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[0][0], "THIS IS AN INTENT_LABEL")
 
     def test_action_load_std_lib(self):
-        mast = self.meta.super_master()
+        mast = self.meta.build_super_master()
         mast.sentinel_register(name="test", code=jtp.action_load_std_lib)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "aload"}
@@ -38,7 +39,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[0], True)
 
     def test_action_load_std_lib_only_super(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.action_load_std_lib)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "aload"}
@@ -47,7 +48,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[0], False)
 
     def test_globals(self):
-        sent = Sentinel(m_id="anon", h=self.meta.hook())
+        sent = Sentinel(m_id="anon", h=self.meta.build_hook())
         gph = Graph(m_id="anon", h=sent._h)
         sent.register_code(jtp.globals)
         test_walker = sent.run_architype("init")
@@ -57,7 +58,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["testing", 56])
 
     def test_net_root_std_lib(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.net_root_std_lib)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -67,7 +68,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertNotEqual(report[1][0], report[1][1])
 
     def test_or_stmt(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.or_stmt)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -75,7 +76,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, [[3.4, "Hello"]])
 
     def test_nd_equals(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.nd_equals_error_correct_line)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -85,7 +86,7 @@ class JacTests(TestCaseHelper, TestCase):
     def test_strange_ability_bug(self):
         import json
 
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.strange_ability_bug)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "travel"}
@@ -105,7 +106,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["Showing", "Showing", "Showing", "Showing"])
 
     def test_node_inheritance(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.node_inheritance, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -127,7 +128,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_inherited_ref(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.inherited_ref, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -135,7 +136,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(len(report["report"]), 12)
 
     def test_node_inheritance_chain_check(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.node_inheritance_chain_check, auto_run=""
         )
@@ -145,7 +146,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["success"], False)
 
     def test_global_reregistering(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.global_reregistering)
         self.assertTrue(mast.active_snt().is_active)
         mast.sentinel_set(snt=mast.active_snt(), code=jtp.global_reregistering)
@@ -154,7 +155,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertTrue(mast.active_snt().is_active)
 
     def test_vector_cos_sim_check(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.vector_cos_sim_check, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -163,7 +164,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(type(report[0]), float)
 
     def test_multi_breaks(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.multi_breaks, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -172,7 +173,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[14], 180)
 
     def test_reffy_deref_check(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.reffy_deref_check, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -181,7 +182,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertTrue(report[1])
 
     def test_vanishing_can_check(self):
-        mast = self.meta.super_master()
+        mast = self.meta.build_super_master()
         mast.actions_load_local("jaseci/tests/infer.py")
         mast.sentinel_register(name="test", code=jtp.vanishing_can_check, auto_run="")
         mast.general_interface_to_api(api_name="walker_run", params={"name": "init"})
@@ -190,7 +191,7 @@ class JacTests(TestCaseHelper, TestCase):
         )["report"]
         self.assertEqual(report, ["2022-01-01T00:00:00"])
         mast.propagate_access("public")
-        mast2 = self.meta.super_master(h=mast._h)
+        mast2 = self.meta.build_super_master(h=mast._h)
         mast.active_snt().run_architype(name="plain", kind="node", caller=mast2)
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -198,7 +199,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report, ["2022-01-01T00:00:00"])
 
     def test_jasecilib_alias_list(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.jasecilib_alias_list, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -206,7 +207,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertGreater(len(report[0].keys()), 3)
 
     def test_jasecilib_params(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.jasecilib_params, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -214,7 +215,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("j_r_acc_ids", report[0][0].keys())
 
     def test_jasecilib_create_user(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.jasecilib_create_user, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -222,7 +223,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report[0]["user"]["name"], "daman@gmail.com")
 
     def test_root_is_node_type(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.root_is_node_type, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -230,7 +231,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"][0], "JAC_TYPE.NODE")
 
     def test_walker_with_exit_after_node(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.walker_with_exit_after_node, auto_run=""
         )
@@ -240,7 +241,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"], [1, 1, 3, 1, 3, 1, 3, 1, 3, 43])
 
     def test_depth_first_take(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.depth_first_take, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -248,7 +249,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"], [1, 2, 3, 4, 5, 6, 7])
 
     def test_breadth_first_take(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.breadth_first_take, auto_run="")
         report = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
@@ -256,7 +257,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"], [1, 2, 5, 3, 4, 6, 7])
 
     def test_inheritance_override_here_check(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.inheritance_override_here_check, auto_run=""
         )
@@ -266,7 +267,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"], [9, 9, 10])
 
     def test_dot_private_hidden(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.dot_private_hidden, auto_run="")
         mast.general_interface_to_api(api_name="walker_run", params={"name": "init"})
         report = mast.general_interface_to_api(
@@ -275,7 +276,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertNotIn("j=", report)
 
     def test_check_destroy_node_has_var(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.check_destroy_node_has_var, auto_run=""
         )
@@ -291,7 +292,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertEqual(report["report"][0], "JAC_TYPE.NULL")
 
     def test_for_loop_dict(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.check_dict_for_in_loop, auto_run=""
         )
@@ -318,7 +319,7 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_var_as_key_for_dict(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(
             name="test", code=jtp.check_dict_for_in_loop, auto_run=""
         )
@@ -330,7 +331,7 @@ class JacTests(TestCaseHelper, TestCase):
         self.assertIn("Key is not str type : <class 'int'>!", res["errors"][0])
 
     def test_new_additional_builtin(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.check_new_builtin, auto_run="")
 
         res = mast.general_interface_to_api(
@@ -343,9 +344,153 @@ class JacTests(TestCaseHelper, TestCase):
         )
 
     def test_continue_issue(self):
-        mast = self.meta.master()
+        mast = self.meta.build_master()
         mast.sentinel_register(name="test", code=jtp.continue_issue, auto_run="")
         res = mast.general_interface_to_api(
             api_name="walker_run", params={"name": "init"}
         )
         self.assertEqual(res["report"], [1, 2, 3, 4, 5, 6, 7, 8, "apple"])
+
+    def test_async_syntax_with_celery(self):
+        mast = self.meta.build_master()
+        mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
+        res = mast.general_interface_to_api(
+            api_name="walker_run",
+            params={"name": "simple_async", "ctx": {"sample": "name"}},
+        )
+
+        self.assertTrue(res["is_queued"])
+
+        res = mast.general_interface_to_api(
+            api_name="walker_queue_wait",
+            params={"task_id": res["result"]},
+        )
+
+        self.assertEqual("test", res["result"]["anchor"])
+
+        res = res["result"]["response"]
+
+        # report from task1 (awaited)
+        self.assertEqual(1, res["report"][0])
+        self.assertEqual(2, res["report"][1])
+
+        # task1 anchor
+        self.assertEqual(1, res["report"][2])
+        report4 = res["report"][4]
+
+        res = res["report"][3]
+
+        # no celery running
+        self.assertTrue(res["is_queued"])
+
+        res = mast.general_interface_to_api(
+            api_name="walker_queue_check",
+            params={"task_id": res["result"]},
+        )
+
+        self.assertEqual(report4, res)
+        self.assertEqual(2, res["result"]["anchor"])
+        self.assertEqual([2, 2], res["result"]["response"]["report"])
+
+    def test_async_syntax_without_celery(self):
+        mast = self.meta.build_master()
+        mast._h.task.state = ServiceState.DISABLED
+        mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
+        res = mast.general_interface_to_api(
+            api_name="walker_run",
+            params={"name": "simple_async", "ctx": {"sample": "name"}},
+        )
+
+        # no celery running
+        self.assertFalse(res["is_queued"])
+
+        # report from task1 (awaited)
+        self.assertEqual(1, res["result"]["report"][0])
+        self.assertEqual(2, res["result"]["report"][1])
+
+        # report from task2 (async but no celery)
+        self.assertEqual(2, res["result"]["report"][2])
+        self.assertEqual(2, res["result"]["report"][3])
+
+        # task1 anchor
+        self.assertEqual(1, res["result"]["report"][4])
+
+        res = res["result"]["report"][5]
+
+        # no celery running
+        self.assertFalse(res["is_queued"])
+        self.assertEqual(2, res["result"])
+
+        mast._h.task.state = ServiceState.RUNNING
+
+    def test_async_sync_syntax_with_celery(self):
+        mast = self.meta.build_master()
+        mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
+        res = mast.general_interface_to_api(
+            api_name="walker_run",
+            params={"name": "simple_async_with_sync", "ctx": {"sample": "name"}},
+        )
+
+        self.assertTrue(res["is_queued"])
+
+        res = mast.general_interface_to_api(
+            api_name="walker_queue_wait",
+            params={"task_id": res["result"]},
+        )
+
+        self.assertEqual("test", res["result"]["anchor"])
+
+        res = res["result"]["response"]
+
+        # report from task1 (awaited)
+        self.assertEqual(1, res["report"][0])
+        self.assertEqual(2, res["report"][1])
+
+        # task1 anchor
+        self.assertEqual(1, res["report"][2])
+        report4 = res["report"][4]
+
+        res = res["report"][3]
+
+        # no celery running
+        self.assertTrue(res["is_queued"])
+
+        res = mast.general_interface_to_api(
+            api_name="walker_queue_check",
+            params={"task_id": res["result"]},
+        )
+
+        self.assertEqual(report4, res)
+        self.assertEqual(2, res["result"]["anchor"])
+        self.assertEqual([2, 2], res["result"]["response"]["report"])
+
+    def test_async_sync_syntax_without_celery(self):
+        mast = self.meta.build_master()
+        mast._h.task.state = ServiceState.DISABLED
+        mast.sentinel_register(name="test", code=jtp.async_syntax, auto_run="")
+        res = mast.general_interface_to_api(
+            api_name="walker_run",
+            params={"name": "simple_async_with_sync", "ctx": {"sample": "name"}},
+        )
+
+        # no celery running
+        self.assertFalse(res["is_queued"])
+
+        # report from task1 (awaited)
+        self.assertEqual(1, res["result"]["report"][0])
+        self.assertEqual(2, res["result"]["report"][1])
+
+        # report from task2 (async but no celery)
+        self.assertEqual(2, res["result"]["report"][2])
+        self.assertEqual(2, res["result"]["report"][3])
+
+        # task1 anchor
+        self.assertEqual(1, res["result"]["report"][4])
+
+        res = res["result"]["report"][5]
+
+        # no celery running
+        self.assertFalse(res["is_queued"])
+        self.assertEqual(2, res["result"])
+
+        mast._h.task.state = ServiceState.RUNNING
