@@ -19,10 +19,14 @@ class IdList(list):
 
     def __init__(self, parent_obj, in_list=None):
         self.parent_obj = parent_obj
+        self.cached_objects = []
         if in_list:
             for i in in_list:
                 self.append(i)
 
+    def cache_reset(self):
+        self.cached_objects = []
+
     def add_obj(self, obj, push_front=False, allow_dups=False, silent=False):
         """Adds a obj obj to Jaseci object"""
         self.parent_obj.check_hooks_match(obj)
@@ -30,6 +34,7 @@ class IdList(list):
             if not silent:
                 logger.warning(str(f"{obj} is already in {self.parent_obj}'s list"))
         else:
+            self.cache_reset()
             if push_front:
                 self.insert(0, obj.jid)
             else:
@@ -40,6 +45,7 @@ class IdList(list):
             self.parent_obj.save()
 
     def add_obj_list(self, obj_list, push_front=False, allow_dups=False, silent=False):
+        self.cache_reset()
         if push_front:
             obj_list.reverse()
         for i in obj_list:
@@ -47,6 +53,7 @@ class IdList(list):
 
     def remove_obj(self, obj):
         """Remove a Jaseci obj from list"""
+        self.cache_reset()
         self.remove(obj.jid)
         self.parent_obj.save()
 
@@ -55,28 +62,26 @@ class IdList(list):
         self.remove_obj(obj)
         obj.destroy()
 
+    def obj_for_id_not_exist_error(self, item_id):
+        my_name = "id_list"
+        for k, v in self.parent_obj.__dict__.items():
+            if v == self:
+                my_name = k
+        return f"{item_id} not found in {my_name} of {self.parent_obj}!"
+
     def get_obj_by_name(self, name, kind=None, silent=False):
         """Returns a Jaseci obj obj by it's name"""
-
-        healing = []
         ret = None
         for i in self:
-            if not self.parent_obj._h.has_obj(uuid.UUID(i)):
-                logger.critical(
-                    str(
-                        f"Self healing: {i} not found "
-                        + f"in id_list of {self.parent_obj}!"
-                    )
-                )
-                healing.append(i)
-                continue
             obj = self.parent_obj._h.get_obj(self.parent_obj._m_id, uuid.UUID(i))
+            if not obj:
+                logger.critical(self.obj_for_id_not_exist_error(i))
+                continue
             if obj.name == name:
                 if kind and obj.kind != kind:
                     continue
-                ret = self.parent_obj._h.get_obj(self.parent_obj._m_id, uuid.UUID(i))
+                ret = obj
                 break
-        self.heal(healing)
         if not ret and not silent:
             logger.error(str(f"object for '{name}' not found in '{self.parent_obj}'!"))
         return ret
@@ -95,24 +100,14 @@ class IdList(list):
 
     def obj_list(self):
         """Return list of objects from ids"""
-        ret = []
-        healing = []
-        for i in self:
-            obj = self.parent_obj._h.get_obj(self.parent_obj._m_id, uuid.UUID(i))
-            if not obj:
-                logger.critical(
-                    str(
-                        f"Self healing: {i} not found "
-                        + f"in id_list of {self.parent_obj}!"
-                    )
-                )
-                healing.append(i)
-            else:
-                ret.append(
-                    self.parent_obj._h.get_obj(self.parent_obj._m_id, uuid.UUID(i))
-                )
-        self.heal(healing)
-        return ret
+        if not len(self.cached_objects):
+            for i in self:
+                obj = self.parent_obj._h.get_obj(self.parent_obj._m_id, uuid.UUID(i))
+                if not obj:
+                    logger.critical(self.obj_for_id_not_exist_error(i))
+                else:
+                    self.cached_objects.append(obj)
+        return self.cached_objects.copy()
 
     def remove_all(self):
         """Remove a Jaseci obj obj by it's name"""
@@ -121,7 +116,7 @@ class IdList(list):
         if len(self):
             logger.critical(
                 str(
-                    f"Removeall all failed in id_list of {self.parent_obj} - "
+                    f"Remove all failed in id_list of {self.parent_obj} - "
                     + f"still has {self}!"
                 )
             )
@@ -138,12 +133,6 @@ class IdList(list):
                 )
             )
 
-    def heal(self, healing):
-        if len(healing):
-            for i in healing:
-                self.remove(i)
-            self.parent_obj.save()
-
     def first_obj(self):
         """Get first object in list"""
         if not self:
